@@ -76,7 +76,7 @@ class StickProtocol():
         deviceId = data['deviceId']
         isSticky = data['isSticky']
         user = self.User.objects.get(id=userId)
-        identityKey = IdentityKey.objects.get(user=user)
+        identityKey = IdentityKey.objects.get(user=user, active=True)
         signedPreKey = SignedPreKey.objects.get(user=user, active=True)
         preKey = PreKey.objects.filter(user=user, used=False).first()
         oneTimeId = user.oneTimeId
@@ -117,7 +117,7 @@ class StickProtocol():
         for id in users_id:
             # If a non-existent user_id was provided, then their id must be removed from the list
             try:
-                identityKey = IdentityKey.objects.get(user__id=id)
+                identityKey = IdentityKey.objects.get(user__id=id, active=True)
             except:
                 toBeRemoved.append(id)
                 continue
@@ -465,6 +465,7 @@ class StickProtocol():
             identityKeysList = IdentityKey.objects.filter(user=user)
             preKeysList = PreKey.objects.filter(user=user)
             senderKeysList = EncryptingSenderKey.objects.filter(user=user)
+            bundle = {}
             identityKeys = []
             for ik in identityKeysList:
                 key = {'id': ik.keyId, 'public': ik.public, 'cipher': ik.cipher, 'salt': ik.salt, 'active': ik.active,
